Commands Guide
==============

.. toctree::
   :maxdepth: 2


   nep        <nep.md>
   gpumd      <gpumd.md>
   select     <select.md>
   vasp       <vasp.md>
   perturb    <perturb.md>
   init       <init.md>
   train      <train.md>
